@@ -67,7 +67,7 @@ class UnityProc:
       port = get_free_port() if port is None else port
       env = os.environ.copy()
 
-      env["UNITONPORT"] = str(port)
+      env["UNITON_PORT"] = str(port)
       # TODO: allow to set cmd line args
       # TODO: figure out how to set -screen-height -screen-width robustly
       self._proc = subprocess.Popen([path], env=env)
@@ -99,6 +99,43 @@ class UnityProc:
 
     self._sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
 
+
+    # bootstrap
+    self._sock.sendall(struct.pack("i", MAGIC_NUMBER))
+
+    from importlib import resources
+    dll = resources.read_binary("uniton", "euniton.dll")
+
+    self._sock.sendall(struct.pack("i", len(dll)))
+    self._sock.sendall(dll)
+    self._sock.close()
+
+
+
+    sleep(1)  # Why do we need this?
+
+    # connect again  TODO: obviously fix this redunancy
+    timeout = time() + 10
+
+    while True:
+      try:
+        self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        self._sock.connect((host, port))
+        break
+      except ConnectionRefusedError:
+        if not self._proc:
+          raise
+        elif self._proc.poll() is not None:
+          raise RuntimeError(f"Process {path} died before Uniton could connect!")
+        elif time() > timeout:
+          raise ConnectionRefusedError(f"Is {path} missing Uniton?")
+        else:
+          sleep(0.1)  # wait, then repeat
+
+    self._sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+
+
+
     # version compatibility check
     magic_number, = struct.unpack('i', recvall(self._sock, 4))
     if magic_number != MAGIC_NUMBER:
@@ -120,6 +157,13 @@ class UnityProc:
       raise ConnectionError(f'Remote Uniton version {self._remote_version} is not compatible with local version {UNITON_VERSION}. Change remote version to {local_version_macro}.* or local version to {remote_version_macro}.* via\n\npip install "uniton=={remote_version_macro}.*" --force-reinstall\n')
 
 
+    # sponsorship check
+    sponsor_error_len, = struct.unpack('i', recvall(self._sock, 4))
+    if sponsor_error_len:
+      msg = recvall(self._sock, sponsor_error_len).decode("utf-8", "strict")
+      raise PermissionError(msg)
+
+
     # init object management
     self._garbage_objects = []
 
